@@ -1,10 +1,10 @@
 #!/bin/sh
 
-if [ ! -f "$1" != "" ]; then
-    echo "need filename"
+if [ ! -f "$1" ]; then
+    echo "need a valid filename"
     exit 1
 fi
-MENU="$1"
+MENU=$(readlink -f "$1")
 
 UTILDIR=utils/
 TOPDIR=./
